env

package module
v0.0.0-...-b97273b Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 28, 2017 License: MIT Imports: 3 Imported by: 2

Documentation

Overview

Package env is a simple configuration solution for building 12 factor apps that are configured via environment variables.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func GetBool

func GetBool(key string) bool

GetBool returns the value associated with the key as a boolean.

func GetInt

func GetInt(key string) int

GetInt returns the value associated with the key as an integer.

func GetString

func GetString(key string) string

GetString returns the value associated with the key as a string.

func SetDefault

func SetDefault(key string, value interface{})

SetDefault sets the default value for this key.

Types

This section is empty.

Jump to